Module engine

Module engine 

Structs

AudioEngine
N-voice mixer with bank playback, dynamic voice allocation, and duty-modulated PWM output.

Enums

VoiceStealingPolicy
Policy for dynamic voice allocation when triggering new effects.