pub fn fill_buffer_into<S: PwmDutySink, const N: usize>(
engine: &mut AudioEngine<'_, N>,
buf: &mut [u16],
sink: &mut S,
) -> usizeExpand description
Fill buf via the engine and write each duty to the sink (DMA kick-off helper).
pub fn fill_buffer_into<S: PwmDutySink, const N: usize>(
engine: &mut AudioEngine<'_, N>,
buf: &mut [u16],
sink: &mut S,
) -> usizeFill buf via the engine and write each duty to the sink (DMA kick-off helper).