Module engine
embedded_
audio
0.2.1
Module engine
Module Items
Structs
Enums
In crate embedded_
audio
embedded_audio
Module
engine
Structs

Audio
Engine
N-voice mixer with bank playback, dynamic voice allocation, and duty-modulated PWM output.
Enums

Voice
Stealing
Policy
Policy for dynamic voice allocation when triggering new effects.